@@ -1,8 +1,10 @@
 __author__ = "jfrog"
-__version__ = "1.1.61"
+__version__ = "1.1.69"
 
 from frogml.sdk.model.decorators.api import api_decorator as api
 from frogml.sdk.model_loggers.model_logger import load_model, log_model
+from frogml.sdk.frogml_client.client import FrogMLClient
+from frogml.sdk.model.base import BaseModel as FrogMlModel
 
 from frogml.core.model_loggers.artifact_logger import (
     load_file,
